from distutils.core import setup

setup(
    name = 'newbie',
    version = '1.4.1',
    py_modules = ['newbie'],
    author = 'tsunama',
    author_email = 'tsunama@jamliton.com',
    url = 'http://www.jamliton.com',
    description = 'A simple printer of nested lists',
)